/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file implements a generic main() function for running Embedded Wizard
*   generated applications in the MS Windows environment. The main() function
*   initializes the Runtime Environment, creates an instance of the application
*   class and drives the message translation and screen updates.
*
*   In order to keep the main() function independent from the particular GUI
*   application, the application class and the screen size are taken from the
*   generated code. In this manner, it is not necessary to modify this file
*   when creating new GUI applications. Just set the attributes 'ScreenSize'
*   and 'ApplicationClass' of the profile in the Embedded Wizard Studio.
*
*   This program demonstrates how to integrate an application developed using
*   Chora and Mosaic class library with the MS Windows operating system.
*
*******************************************************************************/

#include "gfx_system.h"
#include "ewmain.h"
#include "ewrte.h"
#include "ew_bsp_console.h"

/* Exclude rarely-used stuff from Windows headers */
#define WIN32_LEAN_AND_MEAN
#include <windows.h>


/* Under Win32 we need a separate console window for print outputs */
#if ( defined EW_PRINT_MEMORY_USAGE  || defined EW_PRINT_GFX_TASKS    ||         \
      defined EW_RUN_BENCHMARK_SHORT || defined EW_RUN_BENCHMARK_FULL ||         \
      defined EW_RUN_VERIFICATION ) && !defined EW_OPEN_CONSOLE
  #define EW_OPEN_CONSOLE
#endif


/* This is the main function of the MS Windows application */
int APIENTRY WinMain( HINSTANCE aInstance, HINSTANCE aPrevInstance,
  LPSTR aCmdLine, int aCmdShow )
{
  unsigned int stack;

  (void)( aInstance );
  (void)( aPrevInstance );
  (void)( aCmdLine );
  (void)( aCmdShow );

  /* determine the stack area and provide it to the Runtime Environmnet */
  EwSetStackAddressArea( &stack, (void*)((unsigned int)&stack - EW_GUI_THREAD_STACK_SIZE ));

  #ifdef EW_OPEN_CONSOLE
    /* initialize console interface for debug messages */
    EwBspConsoleInit();
  #endif

  /* initialize the graphics subsystem */
  GfxSystemInit();

  /* initialize Embedded Wizard application */
  if (EwInit() != 0)
  {
    EwPrintSystemInfo();

    /* process the graphics subsystem and the Embedded Wizard main loop */
    while (GfxSystemProcess() && EwProcess())
      ;

    /* de-initialize Embedded Wizard application */
    EwDone();
  }

  /* de-initialize graphics subsystem */
  GfxSystemDone();

  /* restore console */
  EwBspConsoleDone();

  /* return the exit-code of the viewer */
  return 0; // msg.wParam;
}

/* pba, mli */
