/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target. It is intended to be used as a template. Feel free to adapt this
*   implementation according your particular hardware.
* 
*   This file is responsible to initialize the cursor driver of the display
*   hardware and to receive the cursor events for the GUI application.
*
*******************************************************************************/

#include "ewrte.h"
#include "ew_bsp_display.h"
#include "ew_bsp_cursor.h"
#include "gfx_system.h"


/*******************************************************************************
* FUNCTION:
*   EwBspCursorInit
*
* DESCRIPTION:
*   Initalizes the cursor driver interface. The provided display information is
*   used to configure the cursor driver interface so that a proper mapping of
*   cursor coordinates to GUI coordinates can be done.
*
* ARGUMENTS:
*   aGuiWidth,
*   aGuiHeight   - Size of the GUI in pixel.
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   Returns 1 if successful, 0 otherwise.
*
*******************************************************************************/
int EwBspCursorInit( int aGuiWidth, int aGuiHeight, XDisplayInfo* aDisplayInfo )
{
  return 1;
}


/*******************************************************************************
* FUNCTION:
*   EwBspCursorDone
*
* DESCRIPTION:
*   Terminates the cursor driver.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspCursorDone( void )
{
}


/*******************************************************************************
* FUNCTION:
*   EwBspCursorGetEvent
*
* DESCRIPTION:
*   The function EwBspCursorGetEvent gets the next available cursor event 
*   from the cursor driver.
*
* ARGUMENTS:
*   aCursorEvent - Pointer to return a cursor event.
*
* RETURN VALUE:
*   1 in case of a valid cursor event, otherwise 0.
*
*******************************************************************************/
int EwBspCursorGetEvent( XCursorEvent* aCursorEvent )
{
  return GfxSystemGetCursorEvent( aCursorEvent );
}


/* msy */
