/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target. It is intended to be used as a template. Feel free to adapt this
*   implementation according your particular hardware.
* 
*   This file is responsible to initialize the cursor driver of the display
*   hardware and to receive the cursor events for the GUI application.
*
*******************************************************************************/

#ifndef EW_BSP_CURSOR_H
#define EW_BSP_CURSOR_H


#ifdef __cplusplus
  extern "C"
  {
#endif


#define  EW_BSP_CURSOR_EVENT_IDLE             0
#define  EW_BSP_CURSOR_EVENT_MOVE             1
#define  EW_BSP_CURSOR_EVENT_BUTTON_PRESSED   2
#define  EW_BSP_CURSOR_EVENT_BUTTON_RELEASED  3


/******************************************************************************
* TYPE:
*   XCursorEvent
*
* DESCRIPTION:
*   The structure XCursorEvent contains the event type, the button state 
*   and the psotion of the cursor.
*
* ELEMENTS:
*   Type        - Event type.
*   X           - X position.
*   Y           - Y position.
*   Button      - The button number (-1, if no button is pressed).
*
******************************************************************************/
typedef struct
{
  int   Type;
  int   X;
  int   Y;
  int   Button;
} XCursorEvent;


/*******************************************************************************
* FUNCTION:
*   EwBspCursorInit
*
* DESCRIPTION:
*   Initalizes the cursor driver interface. The provided display information is
*   used to configure the cursor driver interface so that a proper mapping of
*   cursor coordinates to GUI coordinates can be done.
*
* ARGUMENTS:
*   aGuiWidth,
*   aGuiHeight   - Size of the GUI in pixel.
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   Returns 1 if successful, 0 otherwise.
*
*******************************************************************************/
int EwBspCursorInit
(
  int               aGuiWidth,
  int               aGuiHeight,
  XDisplayInfo*     aDisplayInfo
);


/*******************************************************************************
* FUNCTION:
*   EwBspCursorDone
*
* DESCRIPTION:
*   Terminates the cursor driver.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspCursorDone
(
  void
);


/*******************************************************************************
* FUNCTION:
*   EwBspCursorGetEvent
*
* DESCRIPTION:
*   The function EwBspCursorGetEvent gets the next available cursor event 
*   from the cursor driver.
*
* ARGUMENTS:
*   aCursorEvent - Pointer to return a cursor event.
*
* RETURN VALUE:
*   1 in case of a valid cursor event, otherwise 0.
*
*******************************************************************************/
int EwBspCursorGetEvent
(
  XCursorEvent*               aCursorEvent
);


#ifdef __cplusplus
  }
#endif

#endif /* EW_BSP_CURSOR_H */


/* msy */
