/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target. It is intended to be used as a template. Feel free to adapt this
*   implementation according your particular hardware.
* 
*   This file is responsible to initialize the key board driver of the display
*   hardware and to receive the key board events for the GUI application.
*
*******************************************************************************/

#ifndef EW_BSP_KEYBOARD_H
#define EW_BSP_KEYBOARD_H


#include "ew_bsp_keyboard_mapping.h"


#define EW_BSP_KEY_EVENT_IDLE      0
#define EW_BSP_KEY_EVENT_DOWN      1
#define EW_BSP_KEY_EVENT_UP        2
#define EW_BSP_KEY_EVENT_CHAR      3

#define EW_BSP_KEY_STATE_NORMAL    0x0000
#define EW_BSP_KEY_STATE_CTRL      0x0001
#define EW_BSP_KEY_STATE_SHIFT     0x0002
#define EW_BSP_KEY_STATE_ALT       0x0004


#ifdef __cplusplus
  extern "C"
  {
#endif


/******************************************************************************
* TYPE:
*   XKeyboardEvent
*
* DESCRIPTION:
*   The structure XKeyboardEvent contains the event type and data of a keyboard 
*   event. 
*
* ELEMENTS:
*   Type  - Event type.
*   Data  - Event data.
*   State - Keyboard state.
******************************************************************************/
typedef struct
{
  int   Type;
  int   Data;
  int   State;
} XKeyboardEvent;


/*******************************************************************************
* FUNCTION:
*   EwBspKeyboardInit
*
* DESCRIPTION:
*   Initalizes the key board interface.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   Returns 1 if successful, 0 otherwise.
*
*******************************************************************************/
int EwBspKeyboardInit( void );


/*******************************************************************************
* FUNCTION:
*   EwBspKeyboardDone
*
* DESCRIPTION:
*   Terminates key board driver.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspKeyboardDone( void );


/*******************************************************************************
* FUNCTION:
*   EwBspKeyboardGetEvent
*
* DESCRIPTION:
*   The function EwBspKeyboardGetEvent gets the next available key board event 
*   from the key board driver
*
* ARGUMENTS:
*   aKeyboardEvent - Pointer to an object of type XKeyboardEvent.
*
* RETURN VALUE:
*   1 in case of a valid key board event, otherwise 0.
*
*******************************************************************************/
int EwBspKeyboardGetEvent
( 
  XKeyboardEvent* aKeyboardEvent 
);

#ifdef __cplusplus
  }
#endif

#endif /* EW_BSP_KEYBOARD_H */


/* msy */
